/*
 * rocket2.h --- Include file for rocket2.c, the Comtrol RocketPort2 Linux driver.
 *
 * Written by Kurt Robideau, Copyright 2004.
 * Written by Bijoy Anose, Copyright 2006,2007.
 * Copyright 2004,2006,2007,2008 Comtrol Corporation.    All Rights Reserved.
 * 
 */

#ifndef _ROCKET2_H
#define _ROCKET2_H

#include <asm/io.h>
#include <asm/byteorder.h>
#include <linux/serial.h>
#include <linux/version.h>
#include <linux/termios.h>

#define ROCKET_VERSION "1.16"
#define ROCKET_DATE "18-Jan-2010"

#define RP2_MAJOR_NUMBER  47  

#define Bit(n) (1<<(n))

/*  If defined, uses Linux xx_USE_COUNT mechanism, else uses our own mechanism  */
#define USE_USE_COUNT

#define FIFO_SIZE     512       	/*  FIFO size for both TX and RX FIFO's */
#define XMIT_BUF_SIZE PAGE_SIZE     /* The size of the xmit buffer is 1 page */

/* number of characters left in xmit buffer before we ask for more */
#define WAKEUP_CHARS 256

//#define MAX_NUMBEROF_BOARDS 8 
#define MAX_NUMBEROF_BOARDS 4	//according to our documentation (README, etc)
#define MAX_PORTS_PER_BOARD 32
#define MAX_NUMBEROF_PORTS  (MAX_NUMBEROF_BOARDS * MAX_PORTS_PER_BOARD)

#define RPORT_MAGIC 0x625001

/* 
 *  Bit defines used in TTY processing of received bytes.  There are 2 control words:
 *  - ChP->ignore_status -  bytes with the attribute are dropped
 *  - ChP->report_status -  bytes with the attribute are reported in the flag_buf as bad.  Byte saved.
 */
#define U_PARITY   Bit(0)
#define U_FRAMING  Bit(1)
#define U_BREAK    Bit(2)
#define U_OVERRUN  Bit(3)

/*  Flow control defines  */
#define FLOW_CONTROL_NONE    0
#define FLOW_CONTROL_RTSCTS  1
#define FLOW_CONTROL_XONXOFF 2
#define FLOW_CONTROL_DTRDSR  3

/*
 * Channel rocketModeFlags   //  kdr  Some of these don't relate to rp2
 */
#define ROCKET_CALLOUT_NOHUP    0x00000001
#define ROCKET_FORCE_CD         0x00000002
#define ROCKET_HUP_NOTIFY       0x00000004
#define ROCKET_SPLIT_TERMIOS    0x00000008
#define ROCKET_SPD_MASK         0x00000070
#define ROCKET_SPD_HI           0x00000010      /* Use 56000 instead of 38400 bps */
#define ROCKET_SPD_VHI          0x00000020      /* Use 115200 instead of 38400 bps */
#define ROCKET_SPD_SHI          0x00000030      /* Use 230400 instead of 38400 bps */
#define ROCKET_SPD_WARP         0x00000040      /* Use 460800 instead of 38400 bps */
#define ROCKET_SPD_WARP13       0x00000050      /* Use 921600 instead of 38400 bps */
#define ROCKET_SAK              0x00000080
#define ROCKET_SESSION_LOCKOUT  0x00000100
#define ROCKET_PGRP_LOCKOUT     0x00000200
#define ROCKET_RTS_TOGGLE       0x00000400
#define ROCKET_IS_SMPTE         0x00000800       /* Is an SMPTE card */
#define ROCKET_MODE_MASK        0x00007000
#define ROCKET_MODE_RS232       0x00000000
#define ROCKET_MODE_RS422       0x00001000
#define ROCKET_MODE_RS485       0x00002000       /* 485 2-wire */
#define ROCKET_MODE_RS485FDS    0x00003000       /* 485 4-wire slave */
#define ROCKET_MODE_RS485FDM    0x00004000       /* 485 4-wire master */
#define ROCKET_FLAGS            0x00007FFF

#define ROCKET_INITIALIZED	0x80000000	/* Port is active */
#define ROCKET_CLOSING		0x40000000	/* Serial port is closing */
#define ROCKET_NORMAL_ACTIVE	0x20000000	/* Normal port is active */

#define ROCKET_USR_MASK 0x0071	/* Legal flags that non-privileged
				 * users can set or reset */

/*
 * For closing_wait and closing_wait2
 */
#define ROCKET_CLOSING_WAIT_NONE	65535
#define ROCKET_CLOSING_WAIT_INF		0

#ifndef MIN
#define MIN(a,b)	((a) < (b) ? (a) : (b))
#endif

/*  Some TTY defines  */
#define VERSION_CODE(vers,rel,seq) ( ((vers)<<16) | ((rel)<<8) | (seq) )
//^moved here from rocket2.c, since we added check below:

#if LINUX_VERSION_CODE < VERSION_CODE(2,6,27)
#include <asm/semaphore.h>
#else
#include <linux/semaphore.h>
#endif

#if LINUX_VERSION_CODE > VERSION_CODE(2,5,68)
  #define TTY_GET_LINE(t) t->index
  #define TTY_DRIVER_MINOR_START(t) t->driver->minor_start
  #define TTY_DRIVER_SUBTYPE(t) t->driver->subtype
  #define TTY_DRIVER_NAME(t) t->driver->name
  #define TTY_DRIVER_NAME_BASE(t) t->driver->name_base
  #if LINUX_VERSION_CODE < VERSION_CODE(2,6,26)
    #define TTY_DRIVER_FLUSH_BUFFER_EXISTS(t) t->driver->flush_buffer
    #define TTY_DRIVER_FLUSH_BUFFER(t) t->driver->flush_buffer(t)
    #define TTY_LDISC_FLUSH_BUFFER_EXISTS(t) t->ldisc.flush_buffer
    #define TTY_LDISC_FLUSH_BUFFER(t) t->ldisc.flush_buffer(t)
  #else		// implies kernel >= 2,6,26
    //do this instead. the new api validates the pointer for us
    #define TTY_DRIVER_FLUSH_BUFFER_EXISTS(t) 1
    #define TTY_DRIVER_FLUSH_BUFFER(t) tty_driver_flush_buffer(t)
    #define TTY_LDISC_FLUSH_BUFFER_EXISTS(t) 1
    #define TTY_LDISC_FLUSH_BUFFER(t) tty_ldisc_flush(t)
  #endif		//kernel < 2,6,26
#else		// implies kernel <= 2,5,68
  #define TTY_GET_LINE(t) minor(t->device) - TTY_DRIVER_MINOR_START(t)
  #define TTY_DRIVER_MINOR_START(t) t->driver.minor_start
  #define TTY_DRIVER_SUBTYPE(t) t->driver.subtype
  #define TTY_DRIVER_NAME(t) t->driver.name
  #define TTY_DRIVER_NAME_BASE(t) t->driver.name_base
  #define TTY_DRIVER_FLUSH_BUFFER_EXISTS(t) t->driver.flush_buffer
  #define TTY_DRIVER_FLUSH_BUFFER(t) t->driver.flush_buffer(t)
#endif //  LINUX_VERSION > 2.5.68


/*
 *   Rocketport ioctls
 */
#define RCKP_GET_STRUCT		0x00525001
#define RCKP_GET_CONFIG		0x00525002
#define RCKP_SET_CONFIG		0x00525003
#define RCKP_GET_PORTS		0x00525004
#define RCKP_RESET_RM2		0x00525005
#define RCKP_GET_VERSION	0x00525006
#define RP2_RESET_USE_COUNT	0x00525007


/*  Model Information Struct */
typedef struct {
	unsigned long model;
	char modelString[80];
	unsigned long numPorts;
	int startingPortNumber;
} rocketModel_t;

typedef struct {
	unsigned long model;
	char modelString[80];
	unsigned long numPorts;
	int has_2nd_asic;
} modelInfo_t;

struct rocket_version {
	char rocket_version[32];
	char rocket_date[32];
	char reserved[64];
};

typedef struct {
    int baud;
    int prescale;
    int divisor;
} baudTable_t;

/*  Rocketport Models (the PCI Device ID)  */
//5-2-06 BKA all redefined recently per the following document:
// "\\sidewinder\vault\Administration\Reference_Docs\E279 - PCI Device ID Changes G.xls"
#if 0
#define MODEL_X66_OCTA_RJ45_SEL		0x0040	// 
#define MODEL_X66_32_EXT_IF		0x0041	// 
#define MODEL_X66_8_EXT_IF		0x0042	// 
#define MODEL_X66_16_EXT_IF		0x0043	// 
#define MODEL_X66_4_QUAD_DB_SEL		0x0044	// 
#define MODEL_X66_8_OCTA_DB_SEL		0x0045	// 
#define MODEL_X66_4_EXT_IF		0x0046	// 
#define MODEL_X66_4_RJ45		0x0047	// 
#else
//taken from E279 document on 5-15-07 BKA
//-------------PCI-X CARDS--------------
#define MODEL_X66_OCTA_RJ45_SEL		0x0040	// 
#define MODEL_X66_32_EXT_IF		0x0041	// 
#define MODEL_X66_8_EXT_IF		0x0042	// 
#define MODEL_X66_16_EXT_IF		0x0043	// 
#define MODEL_X66_4_QUAD_DB_SEL		0x0044	// 
#define MODEL_X66_8_OCTA_DB_SEL		0x0045	// 
#define MODEL_X66_4_EXT_IF		0x0046	// 
#define MODEL_X66_4_RJ45		0x0047	// 
#define MODEL_X66_PLUS_QUAD		0x004A
#define MODEL_X66_PLUS_OCTA		0x004B
#define MODEL_X66_RM_III_8		0x004C
#define MODEL_X66_RM_III_4		0x004D
#define MODEL_X66_PLUS_2_232		0x004E
#define MODEL_X66_2_SMPTE		0x004F
#define MODEL_X66_PLUS_4_RJ45		0x0050
#define MODEL_X66_PLUS_8_RJ11		0x0051
#define MODEL_X66_OCTA_SMPTE		0x0052
//-------------PCI-e CARDS--------------
#define MODEL_EXP_OCTA_RJ45_SEL		0x0060	// 
#define MODEL_EXP_32_EXT_IF		0x0061	// 
#define MODEL_EXP_8_EXT_IF		0x0062	// 
#define MODEL_EXP_16_EXT_IF		0x0063	// 
#define MODEL_EXP_4_QUAD_DB_SEL		0x0064	// 
#define MODEL_EXP_8_OCTA_DB_SEL		0x0065	// 
#define MODEL_EXP_4_EXT_IF		0x0066	// 
#define MODEL_EXP_4_RJ45		0x0067	// 
#define MODEL_EXP_2_SMPTE		0x006F
#define MODEL_EXP_PLUS_8_RJ11		0x0071
#define MODEL_EXP_OCTA_SMPTE		0x0072
#endif


/* Channel level information structure */
typedef struct {
    void *pBaseRegister;  /*  Base ptr to port registers */
    void *ucodeAddr;      /*  Base ptr to the channel's Receive Processor microcode. */
    
    int channelNumber;         /*  The ASIC channel number (0-31) */
    int portNumber;            /*  The port number /dev/ttyRPx (x) number assigned to the TTY layer */
    int xmit_flag;             /*  Flag indicating there is data to be transmitted */
    
    /*  old r_port stuff */
    
    int magic;
    int modeFlags;                /*  Mode flags (RS233, INITIALIZED, etc.)  */
    int count;                    /*  How may processes have this port open */
    int blocked_open;             /*  Flag indicating port is blocking, waiting to open */
    struct tty_struct *rptty;
    int closing_wait;
    int close_delay;
    int monitorCdChange;          /*  A TTY thing, the flag CLOCAL controls whether delta CD's is acted upon  */
    
    /*  The XMIT buffer */
    unsigned char *xmit_buf;
    int xmit_head;
    int xmit_tail;
    int xmit_cnt;              /*  Number of bytes in the XMIT buffer */
    int xmit_fifo_room;        /*  Amount of room in the TX FIFO  */
    
//	int session;
//	int pgrp;
    int cd_status;
    
    int ignore_status;         /* TTY byte processing, see above */
    int report_status;         
    
    int cps;                   /*  Character per second value, used when waiting for a drain */
    struct termios normal_termios;

#if LINUX_VERSION_CODE < VERSION_CODE(2,6,10)
	unsigned char *tmp_buf;
	struct semaphore tmp_buf_sem;
#endif      
    
#ifdef DECLARE_WAITQUEUE
    wait_queue_head_t open_wait;
    wait_queue_head_t close_wait;
    wait_queue_head_t delta_msr_wait;  //  Queue of processes waiting on a MSR change 
#else
    struct wait_queue *open_wait;
    struct wait_queue *close_wait;
    struct wait_queue *delta_msr_wait;
#endif
    struct async_icount icount;  /*  Keeps count of MSR line changes */
    int am_delta_msr_waiting;    /*  Flag, indicating a process has called TIOCMIWAIT and is sleeping */
    unsigned long last_msr;      /*  The last MSR values read */
    
    spinlock_t slock;

} CHANNEL_T;


/* Controller level information structure */
typedef struct {
	int controllerNumber;                         /*  Controller number (0-n) */
	int numPorts;                                 /*  Number of channels (serial ports) */
	int startingPort;                             /*  Starting port number ttyRPx (x) assigned by the TTY layer */
	rocketModel_t rocketModel;  

         /*  Model information */
	int clockPrescale;                            
	int has_2nd_asic;                             /*  Set if board has 2 Unity ASICs */

	CHANNEL_T channel[MAX_PORTS_PER_BOARD];       /*  One channel structure per serial port */


	void *pBasePciRegion0;               //  Base memory address region 0
	void *pBasePciMemory;                //  Base memory address region 1
} CONTROLLER_T;

/*  Debugging MACROS  */

//#define ROCKET_DEBUG_ALL

#ifdef ROCKET_DEBUG_ALL

#define ROCKET_DEBUG_OPEN
#define ROCKET_DEBUG_CLOSE
#define ROCKET_DEBUG_INTR
#define ROCKET_DEBUG_IO
#define ROCKET_DEBUG_WRITE
#define ROCKET_DEBUG_READ
#define ROCKET_DEBUG_FLOW
#define ROCKET_DEBUG_WAIT_UNTIL_SENT
#define ROCKET_DEBUG_DELTA_MSR

#endif // ROCKET_DEBUG_ALL

#ifdef ROCKET_DEBUG_OPEN
#  define DOPEN(fmt, args...) printk(KERN_INFO "RP2: " fmt, ## args)
#else
#  define DOPEN(fmt, args...) 
#endif

#ifdef ROCKET_DEBUG_CLOSE
#  define DCLOSE(fmt, args...) printk(KERN_INFO "RP2: " fmt, ## args)
#else
#  define DCLOSE(fmt, args...) 
#endif

#ifdef ROCKET_DEBUG_IO
#  define DIO(fmt, args...) printk(KERN_INFO "RP2: " fmt, ## args)
#else
#  define DIO(fmt, args...) 
#endif

#ifdef ROCKET_DEBUG_WRITE
#  define DWRITE(fmt, args...) printk(KERN_INFO "RP2: " fmt, ## args)
#else
#  define DWRITE(fmt, args...) 
#endif

#ifdef ROCKET_DEBUG_READ
#  define DREAD(fmt, args...) printk(KERN_INFO "RP2: " fmt, ## args)
#else
#  define DREAD(fmt, args...) 
#endif

#ifdef ROCKET_DEBUG_INTR
#  define DINTR(fmt, args...) printk(KERN_INFO "RP2: " fmt, ## args)
#else
#  define DINTR(fmt, args...) 
#endif

#ifdef ROCKET_DEBUG_DELTA_MSR
#  define DMSR(fmt, args...) printk(KERN_INFO "RP2: " fmt, ## args)
#else
#  define DMSR(fmt, args...) 
#endif

#ifdef ROCKET_DEBUG_WAIT_UNTIL_SENT
#  define DWSENT(fmt, args...) printk(KERN_INFO "RP2: " fmt, ## args)
#else
#  define DWSENT(fmt, args...) 
#endif

#endif // _ROCKET2_H
