/**********************************************************************
 *
 *        unity.h
 *
 *        Prototypes for the Unity accessor functions found in unity.c.
 *        Register and bit definitions for the Unity ASIC.
 * 
 **********************************************************************/

#ifndef _UNITY_H
#define _UNITY_H

#define Bit(n) (1<<(n))

#ifndef TRUE
#define TRUE 1
#endif

#ifndef FALSE
#define FALSE 0
#endif

/* Use these macro's to read/write PCI memory space.  */
#define READB(addr)  (readb(addr))
#define READW(addr)  (readw(addr))
#define READL(addr)  (readl(addr))

#define WRITEB(val, addr) (writeb(val,addr))
#define WRITEW(val, addr) (writew(val,addr))
#define WRITEL(val, addr) (writel(val,addr))

/*  Overall memory map */
#define PORT_REGS_BASE_ADDR        0x0000
#define UCODE_SRAM_CORE0           0x0400
#define UCODE_SRAM_CORE1           0x0800
#define ASIC_CLOCK_PRESCALER       0x0C00
#define CHANNEL_INT_STATUS         0x0C04
#define CHANNEL_INT_MASK           0x0C08
#define AIOP_CLOCK                 0x0C0C
#define ASIC_INT_STATUS            0x0D00
#define ASIC_CONFIGURATION         0x0D04
#define MODEM_RESET                0x0D08
#define GLOBAL_COMMAND             0x0D0C

#define I2C_CONTROLLER             0x2000
#define DMA_CONTROLLER             0x2400


/*  Port Register Offsets */
#define RCV_DATA_BLOCK             0x0000
#define XMIT_DATA_BLOCK            0x0000
#define RCV_DATA_WORD              0x0004
#define XMIT_DATA_WORD             0x0004
#define RCV_DATA_BYTE_STATUS       0x0008
#define XMIT_DATA_BYTE             0x0008
#define RCV_FIFO_COUNT             0x000C
#define XMIT_FIFO_COUNT            0x000E
#define INT_ID_CHAN_STATUS         0x0010
#define XMIT_CTRL_RCV_CTRL         0x0014
#define UART_CTRL                  0x0018
#define BAUD_RATE_GENERATOR        0x001C
#define INTERCHAR_RELOAD_VAL       0x0020
#define PRIORITY_XMIT_WORD         0x0024
#define PRIORITY_XMIT_BYTE         0x0028

/*  Bit defines for RCV_DATA_BYTE_STATUS (offset 0x08) */
#define RCV_BYTE_PARITY_ERROR      Bit(8)
#define RCV_BYTE_RCV_OVERRUN       Bit(9)
#define RCV_BYTE_FRAMING_ERROR     Bit(10)
#define RCV_BYTE_BREAK_DETECTED    Bit(11)
#define RCV_BYTE_ADDRESS_BYTE      Bit(12)
#define RCV_BYTE_TIMEOUT_DETECTED  Bit(13)

/*  Bit defines for INT_ID_CHAN_STATUS (offset 0x10) */
#define CHAN_STATUS_RCV_DATA_AVAIL           Bit(0)
#define CHAN_STATUS_XMIT_SHIFT_REG_EMPTY     Bit(1)
#define CHAN_STATUS_XMIT_FIFO_EMPTY          Bit(2)
#define CHAN_STATUS_CD_ACTIVE                Bit(3)
#define CHAN_STATUS_DSR_ACTIVE               Bit(4)
#define CHAN_STATUS_CTS_ACTIVE               Bit(5)
#define CHAN_STATUS_RI_ACTIVE                Bit(6)
#define CHAN_STATUS_RTS_IN_STATUS            Bit(7)
#define CHAN_STATUS_PARITY_ERROR             Bit(8)
#define CHAN_STATUS_FRAMING_ERROR            Bit(9)
#define CHAN_STATUS_BREAK_DETECTED           Bit(10)
#define CHAN_STATUS_COMPARE1                 Bit(11)
#define CHAN_STATUS_COMPARE2                 Bit(12)
#define CHAN_STATUS_RCV_OVERFLOW             Bit(13)
#define CHAN_STATUS_PRIORITY_BUFFER_FULL     Bit(14)

#define ChanStatus_RxErr  ( CHAN_STATUS_PARITY_ERROR   | \
                            CHAN_STATUS_FRAMING_ERROR  | \
                            CHAN_STATUS_BREAK_DETECTED | \
                            CHAN_STATUS_RCV_OVERFLOW )

#define INT_DSR_CHANGE             Bit(16)
#define INT_CTS_CHANGE             Bit(17)
#define INT_CD_CHANGE              Bit(18)
#define INT_SPECIAL_RECEIVE        Bit(19)
#define INT_XMIT_FIFO_EMPTY        Bit(20)
#define INT_RCV_FIFO_TRIGGER       Bit(21)
#define INT_RI_CHANGE              Bit(22)
#define INT_RCV_DATA_RDY           Bit(23)
#define INT_ADDR_RCVD              Bit(24)
#define INT_XMIT_SHIFTREG_EMPTY    Bit(25)
#define INT_XMIT_FIFO_TRIGGER      Bit(26)
#define INT_INTERCHAR_TIMEOUT      Bit(27)


/*  Bit defines for XMIT_CTRL_RCV_CTRL (offset 0x14) */
#define MDM_CHANGE_INT_EN          Bit(0)
#define SPECIAL_RCV_INT_EN         Bit(2)
#define RCV_FIFO_TRIGGER0          Bit(3)
#define RCV_FIFO_TRIGGER1          Bit(4)
#define RCV_PROC_EN                Bit(5)
#define RTS_FLOW_EN                Bit(6)
#define DTR_FLOW_EN                Bit(7)
#define ONE_STOP_BIT_EN            Bit(8)
#define RCV_DATA_RDY_INT_EN        Bit(9)
#define ADDRESS_INT_EN             Bit(10)
#define INTERCHAR_TIMEOUT_INT_EN   Bit(11)
#define INTERCHAR_STATUS_EN        Bit(12)

#define XMIT_FIFO_TRIGGER1         Bit(16)
#define XMIT_FIFO_TRIGGER2         Bit(17)
#define DSR_FLOW_EN                Bit(18)
#define XMIT_SHIFTREG_INT_EN       Bit(19)
#define XMIT_FIFO_INT_EN           Bit(20)
#define RTS_TOGGLE_POLARITY        Bit(21)
#define RTS_TOGGLE                 Bit(22)
#define CTS_FLOW_EN                Bit(23)
#define XMIT_EN                    Bit(24)
#define SET_RTS_ACTIVE             Bit(25)
#define SET_DTR_ACTIVE             Bit(26)
#define LOCAL_LOOPBACK             Bit(27)
#define BREAK_ON                   Bit(28)
#define FORCE_PARITY               Bit(29)
#define EVEN_PARITY                Bit(30)
#define PARITY_ON                  Bit(31)


/*  Bit defines for UART_CTRL (offset 0x18) */
#define INTERFACE_SELECT0          Bit(0)
#define INTERFACE_SELECT1          Bit(1)
#define INTERFACE_SELECT2          Bit(2)
#define FLUSH_RCV_FIFO             Bit(3)
#define FLUSH_XMIT_FIFO            Bit(4)
#define RESET_CHANNEL              Bit(5)
#define RCV_PROC_XMIT_EN           Bit(6)
#define FLUSH_PRIORITY_FIFO        Bit(7)
#define DATA_BITS0                 Bit(8)
#define DATA_BITS1                 Bit(9)
#define STOP_BITS                  Bit(10)

/*  Bit defines for ASIC_INT_STATUS */
#define DMA_INT_ACTIVE             Bit(0)
#define AIOP0_INT_ACTIVE           Bit(4)
#define AIOP1_INT_ACTIVE           Bit(5)
#define AIOP2_INT_ACTIVE           Bit(6)
#define AIOP3_INT_ACTIVE           Bit(7)
#define AIOP_INT_EN                Bit(20)

/*  Bit defines for ASIC_CONFIGURATION (offset 0x704) */
#define BUS_MODE0                  Bit(0)
#define BUS_MODE1                  Bit(1)
#define TDM_MODE                   Bit(2)
#define TDM_IF                     Bit(3)
#define EIGHT_PORT_IF              Bit(4)
#define MODEM_RESET_SELECT         Bit(5)
#define DOUBLE_DATA                Bit(6)
#define TDM_CLK_SPEED0             Bit(8)
#define TDM_CLK_SPEED1             Bit(9)
#define TDM_TEST                   Bit(10)
#define SLOW_CLOCK                 Bit(11)

/*  Bit defines for the XMIT FIFO Trigger level of the XMIT_CTRL_RCV_CTRL register */
#define UXMIT_FIFO_TRIG_MASK       (Bit(17) | Bit(16))
#define UXMIT_FIFO_TRIG_DISABLED   (0x00)
#define UXMIT_FIFO_TRIG_1_8        (Bit(16))
#define UXMIT_FIFO_TRIG_1_4        (Bit(17))
#define UXMIT_FIFO_TRIG_1_2        (Bit(17) | Bit(16))

/*  Bit defines for the RCV FIFO Trigger level of the XMIT_CTRL_RCV_CTRL register */
#define URCV_FIFO_TRIG_MASK       (Bit(4) | Bit(3))
#define URCV_FIFO_TRIG_DISABLED   (0x00)
#define URCV_FIFO_TRIG_1_CHAR     (Bit(3))
#define URCV_FIFO_TRIG_1_2        (Bit(4))
#define URCV_FIFO_TRIG_7_8        (Bit(4) | Bit(3))

/*  Data bit defines, unique to UNITY.  */
#define DATABITS_MASK (Bit(9) | Bit(8))	
#define DATABITS_5    (0x00)
#define DATABITS_6    (Bit(8))
#define DATABITS_7    (Bit(9))
#define DATABITS_8    (Bit(9) | Bit(8))

/*  RS mode bit defines, unique to UNITY.  */
#define URS_MASK             (Bit(2) | Bit(1) | Bit(0))	
#define URS_DISABLED         (0x00)
#define URS_RS232            (Bit(0))
#define URS_RS422            (Bit(1))
#define URS_RS485_FD_MASTER  (Bit(1))
#define URS_RS485_FD_SLAVE   (Bit(1) | Bit(0))
#define URS_RS485_HD         (Bit(2))
#define URS_RS485_TEST       (Bit(2) | Bit(0))
#define URS_RESERVED         (Bit(2) | Bit(1))
#define URS_DEBUG            (Bit(2) | Bit(1) | Bit(0))

#define	isPCI	1
#define AIOPID_0001 0x0001	/* AIOP release 1 */

/*  Unity Receive Processor Microcode Function Addresses and Values  */
#define URP_RCV_FIFO                    0x37    /*  Receive FIFO enable/disable  */
#define URP_RCV_FIFO_ENABLE             0x08
#define URP_RCV_FIFO_DISABLE            0x81

#define URP_TX_SW_FLOW_CONTROL          0x02    /*  Transmit software flow control enable/disable */
#define URP_TX_SW_FLOW_CONTROL_ENABLE   0x81 
#define URP_TX_SW_FLOW_CONTROL_DISABLE  0x9D

#define URP_RX_SW_FLOW_CONTROL          0x0C    /*  Receive software flow control enable/disable */
#define URP_RX_SW_FLOW_CONTROL_ENABLE   0x81 
#define URP_RX_SW_FLOW_CONTROL_DISABLE  0x8D

#define URP_XANY                        0x07    /*  Software flow control XANY enable/disable */
#define URP_XANY_ENABLE                 0x83
#define URP_XANY_DISABLE                0x98

#define URP_COMPARE1                    0x21   /*  Compare #1 enable/disable */
#define URP_COMPARE1_ENABLE             0x81
#define URP_COMPARE1_DISABLE            0x89

#define URP_COMPARE_IRQ1                0x25   /*  Compare #1 IRQ enable/disable */
#define URP_COMPARE_IRQ1_ENABLE         0x11
#define URP_COMPARE_IRQ1_DISABLE        0x81

#define URP_COMPARE_ACTION1             0x26   /*  Compare #1 action */
#define URP_COMPARE_ACTION1_SAVE        0x91
#define URP_COMPARE_ACTION1_REPLACE     0x81
#define URP_COMPARE_ACTION1_DISCARD     0x0A

#define URP_COMPARE2                    0x2A   /*  Compare #2 enable/disable */
#define URP_COMPARE2_ENABLE             0x81
#define URP_COMPARE2_DISABLE            0x89

#define URP_COMPARE_IRQ2                0x2E   /*  Compare #2 IRQ enable/disable */
#define URP_COMPARE_IRQ2_ENABLE         0x10
#define URP_COMPARE_IRQ2_DISABLE        0x81

#define URP_COMPARE_ACTION2             0x2F   /*  Compare #2 action */
#define URP_COMPARE_ACTION2_SAVE        0x88
#define URP_COMPARE_ACTION2_REPLACE     0x81
#define URP_COMPARE_ACTION2_DISCARD     0x0A

#define URP_STRIP_NULLS                 0x33   /*  Strip Nulls */
#define URP_STRIP_NULLS_ENABLE          0xC2
#define URP_STRIP_NULLS_DISABLE         0x84

/*  Unity Receive Processor Microcode Variable Addresses  */
#define URP_MASK           0x20
#define URP_COMPARE_BYTE1  0x23
#define URP_REPLACE_BYTE1  0x28
#define URP_COMPARE_BYTE2  0x2C
#define URP_REPLACE_BYTE2  0x31
#define URP_XMIT_XOFF_CHAR 0x11
#define URP_RCV_XOFF_CHAR  0x04
#define URP_XMIT_XON_CHAR  0x16
#define URP_RCV_XON_CHAR   0x06

/*  Flextronics PCI IP Core Configuration Interrupt Control Register  */
#define PCI_INTERRUPT_CONTROL       0x1EC
#define PCI_INTERRUPT_ENABLE        Bit(0)
#define PCI_WISHBONE_ERROR_ENABLE   Bit(1)
#define PCI_ERROR_ENABLE            Bit(2)
#define PCI_PARITY_ERROR_ENABLE     Bit(3)
#define PCI_SYSTEM_ERROR_ENABLE     Bit(4)

/*  Flextronics PCI IP Core Configuration Interrupt Status Register  */
#define PCI_INTERRUPT_STATUS        0x1F0
#define PCI_INTERRUPT_STATUS_BIT    Bit(0)
#define PCI_WISHBONE_ERROR          Bit(1)
#define PCI_ERROR                   Bit(2)
#define PCI_PARITY_ERROR            Bit(3)
#define PCI_SYSTEM_ERROR            Bit(4)

/*  DMA Registers */
#define DMA_MASTER_CONTROL            0x0000
#define DMA_PRIORITY_CONFIG           0x0004
#define DMA_TRIGGER_STATUS            0x0008
#define DMA_CONFIG                    0x000C
#define DMA_SRC_ADDR                  0x0010
#define DMA_DEST_ADDR                 0x0014

/*  DMA Master Control Register defines */
#define DMA_ENABLE                    Bit(0)
#define DMA_INTERRUPT_ENABLE          Bit(1)
#define DMA_CHANNEL_ENABLE            Bit(2)

/*  DMA Trigger/Status Register defines */
#define DMA_TRIGGER                   Bit(0)
#define DMA_CLEAR_TRIGGER             Bit(4)
#define DMA_ABORT                     Bit(8)
#define DMA_ACTIVE                    Bit(9)
#define DMA_WB_ERROR_SRC              Bit(14)
#define DMA_WB_ERROR_DEST             Bit(15)

/*  DMA Channel Configuration Register defines */
#define DMA_CHANNEL_INTERRUPT_ENABLE  Bit(28)
#define DMA_SRC_INCREMENT_ADDR        Bit(29)
#define DMA_DEST_INCREMENT_ADDR       Bit(30)
#define DMA_USE_LINKED_LIST           Bit(31)

/*  Flextronics PCI IP Core EEPROM Control Register  */
//#define EEPROM_CTRL                 0x3FC
#define EEPROM_CTRL                 0x2FC

#define EEPROM_READ                 Bit(24)
#define EEPROM_WRITE                Bit(25)
#define EEPROM_NO_ACK               Bit(31)

#include "rocket2.h"

#ifndef TTY_FLIPBUF_SIZE
#define TTY_FLIPBUF_SIZE 512
#endif

/*  Prototypes */
void uSetClockPrescale(CONTROLLER_T *CtlP, unsigned int prescale);
void uSetTDMClockRate(CONTROLLER_T *CtlP);
void uGlobalReset(CONTROLLER_T *CtlP);
void uChannelReset(CHANNEL_T *ChP);
void uSetBaudDivisor(CHANNEL_T *ChP, unsigned int divisor);
void uSetIntercharValue(CHANNEL_T *ChP, unsigned int value);
void uFlushRxFifo(CHANNEL_T *ChP);
void uFlushTxFifo(CHANNEL_T *ChP);
void uStopRxProcessor(CHANNEL_T *ChP);
void uStartRxProcessor(CHANNEL_T *ChP);
void uClrBreak(CHANNEL_T *ChP);
void uSendBreak(CHANNEL_T *ChP);
void uClrDtr(CHANNEL_T *ChP);
void uSetDtr(CHANNEL_T *ChP);
void uClrRts(CHANNEL_T *ChP);
void uSetRts(CHANNEL_T *ChP);
void uDisAiop(CONTROLLER_T *CtlP, int i);
void uDisCtsFlowCtrl(CHANNEL_T *ChP);
void uEnCtsFlowCtrl(CHANNEL_T *ChP);
void uEnRtsFlowCtrl(CHANNEL_T *ChP);
void uDisRtsFlowCtrl(CHANNEL_T *ChP);
void uDisParity(CHANNEL_T *ChP);
void uEnParity(CHANNEL_T *ChP);
void uEnForcedParity(CHANNEL_T *ChP);
void uDisForcedParity(CHANNEL_T *ChP);
void uDisRTSToggle(CHANNEL_T *ChP);
void uEnRTSToggle(CHANNEL_T *ChP);
void uEnRcvProcessor(CHANNEL_T *ChP);
void uDisRcvProcessor(CHANNEL_T *ChP);
void uDisRxFIFO(CHANNEL_T *ChP);
void uEnRxFIFO(CHANNEL_T *ChP);
void uDisTransmit(CHANNEL_T *ChP);
void uEnTransmit(CHANNEL_T *ChP);
void uEnStripNulls(CHANNEL_T *ChP);
void uDisStripNulls(CHANNEL_T *ChP);
void uDisSoftFlowCtrl(CHANNEL_T *ChP);
void uEnSoftFlowCtrl(CHANNEL_T *ChP);
void uSetMask(CHANNEL_T *ChP, unsigned char mask);
void uEnReplace1(CHANNEL_T *ChP, unsigned char replaceChar);
void uDisReplace1(CHANNEL_T *ChP);
void uEnReplace2(CHANNEL_T *ChP, unsigned char replaceChar);
void uDisReplace2(CHANNEL_T *ChP);
void uEnCompare1(CHANNEL_T *ChP, unsigned char compareAction, unsigned char compareChar, unsigned char replaceChar);
void uEnCompare2(CHANNEL_T *ChP, unsigned char compareAction, unsigned char compareChar, unsigned char replaceChar);
void uDisCompare1(CHANNEL_T *ChP);
void uDisCompare2(CHANNEL_T *ChP);
void uSetTxXOFFChar(CHANNEL_T *ChP, char ch);
void uSetTxXONChar(CHANNEL_T *ChP, char ch);
void uSetRxXOFFChar(CHANNEL_T *ChP, char ch);
void uSetRxXONChar(CHANNEL_T *ChP, char ch);
void uSetStop1(CHANNEL_T *ChP);
void uSetStop2(CHANNEL_T *ChP);
void uSetRxTrigger(CHANNEL_T *ChP, unsigned int level);
void uSetTxTrigger(CHANNEL_T *ChP, unsigned int level);
void uSetEvenParity(CHANNEL_T *ChP);
void uSetOddParity(CHANNEL_T *ChP);
void uSetDataBits(CHANNEL_T *ChP, unsigned int level);
void uSetData5(CHANNEL_T *ChP);
void uSetData6(CHANNEL_T *ChP);
void uSetData7(CHANNEL_T *ChP);
void uSetData8(CHANNEL_T *ChP);
unsigned short uGetTxCnt(CHANNEL_T *ChP);
unsigned short uGetRxCnt(CHANNEL_T *ChP);
void uSetInterfaceMode(CHANNEL_T *ChP, unsigned int mode);
void uEnLoopbackMode(CHANNEL_T *ChP);
void uDisLoopbackMode(CHANNEL_T *ChP);
void uRtsTogglePolarityHigh(CHANNEL_T *ChP);
void uRtsTogglePolarityLow(CHANNEL_T *ChP);
void uEnDsrFlowCtrl(CHANNEL_T *ChP);
void uDisDsrFlowCtrl(CHANNEL_T *ChP);
void uEnDtrFlowCtrl(CHANNEL_T *ChP);
void uDisDtrFlowCtrl(CHANNEL_T *ChP);
int uGetChanRI(CHANNEL_T * ChP);
int uShiftRegisterEmpty(CHANNEL_T * ChP);
void uXmitByte(CHANNEL_T *ChP, unsigned char val);
void uXmitWord(CHANNEL_T *ChP, unsigned short val);
void uXmitDword(CHANNEL_T *ChP, unsigned int val);
void uXmitBytePriority(CHANNEL_T *ChP, unsigned char pval);
void uXmitWordPriority(CHANNEL_T *ChP, unsigned short pval);
void uXmitDwordPriority(CHANNEL_T *ChP, unsigned int pval);
unsigned short uRxByteStatus(CHANNEL_T *ChP);
unsigned short uRxWord(CHANNEL_T *ChP);
unsigned int uRxDword(CHANNEL_T *ChP);

/*  Interrupts functions */
void uEnableGlobalInterrupts(CONTROLLER_T *CtlP);
void uDisableGlobalInterrupts(CONTROLLER_T *CtlP);
int uGlobalInterruptsAreEnabled(CONTROLLER_T *CtlP);
void uEnableAiopInterrupts(CONTROLLER_T *CtlP);
void uDisableAiopInterrupts(CONTROLLER_T *CtlP);
void uClearGlobalInts(CONTROLLER_T *CtlP);
void uEnXmitFifoEmptyInt(CHANNEL_T *ChP);
void uDisXmitFifoEmptyInt(CHANNEL_T *ChP);
void uEnXmitShiftRegEmptyInt(CHANNEL_T *ChP);
void uDisXmitShiftRegEmptyInt(CHANNEL_T *ChP);
void uEnInterCharTimeoutInt(CHANNEL_T *ChP);
void uDisInterCharTimeoutInt(CHANNEL_T *ChP);
void uEnInterCharTimeoutStatus(CHANNEL_T *ChP);
void uDisInterCharTimeoutStatus(CHANNEL_T *ChP);
void uEnAddRcvdInt(CHANNEL_T *ChP);
void uDisAddRcvdInt(CHANNEL_T *ChP);
void uEnRcvDataReadyTimeoutInt(CHANNEL_T *ChP);
void uDisRcvDataReadyTimeoutInt(CHANNEL_T *ChP);
void uEnSpecialReceiveInt(CHANNEL_T *ChP);
void uDisSpecialReceiveInt(CHANNEL_T *ChP);
void uEnModemChangeInt(CHANNEL_T *ChP);
void uDisModemChangeInt(CHANNEL_T *ChP);
int uInterruptActive(CONTROLLER_T *CtlP);
int uDmaInterruptActive(CONTROLLER_T *CtlP);
int uAiop0InterruptActive(CONTROLLER_T *CtlP);
int uAiop1InterruptActive(CONTROLLER_T *CtlP);
int uAiop2InterruptActive(CONTROLLER_T *CtlP);
int uAiop3InterruptActive(CONTROLLER_T *CtlP);
int uAnyAiopInterrruptActive(CONTROLLER_T *CtlP);
int uXmitFifoTriggerInt(CHANNEL_T *ChP);
int uRcvFifoTriggerInt(CHANNEL_T *ChP);
int uRcvDataRdyInt(CHANNEL_T *ChP);
int uXmitFifoEmptyInt(CHANNEL_T *ChP);
int uXmitShiftRegEmptyInt(CHANNEL_T *ChP);
int uInterCharTimeoutInt(CHANNEL_T *ChP);
int uAddrRcvdInt(CHANNEL_T *ChP);
int uSpecialReceiveInt(CHANNEL_T *ChP);
void uClrSpecialReceiveInt(CHANNEL_T *ChP);
int uIntDsrChange(CHANNEL_T *ChP);
int uIntCtsChange(CHANNEL_T *ChP);
int uIntCdChange(CHANNEL_T *ChP);
int uIntRiChange(CHANNEL_T *ChP);

/*  Channel Status functions */
unsigned int uGetChanStatus(CHANNEL_T *ChP);
int uClrChanStatus(CHANNEL_T *ChP);
int uChanStatusRcvOverrun(CHANNEL_T *ChP);
int uChanStatusBreakDetected(CHANNEL_T *ChP);
int uChanStatusParityError(CHANNEL_T *ChP);
int uChanStatusFramingError(CHANNEL_T *ChP);
int uPriorityBufferFull(CHANNEL_T *ChP);
int uChanStatusCompare2(CHANNEL_T *ChP);
int uChanStatusCompare1(CHANNEL_T *ChP);
int uRiActive(CHANNEL_T *ChP);
int uCtsActive(CHANNEL_T *ChP);
int uDsrActive(CHANNEL_T *ChP);
int uDtrActive(CHANNEL_T *ChP);
int uRtsActive(CHANNEL_T *ChP);
int uCdActive(CHANNEL_T *ChP);
int uXmitFifoEmpty(CHANNEL_T *ChP);
int uXmitShiftRegEmpty(CHANNEL_T *ChP);
int uRcvDataAvail(CHANNEL_T *ChP);
int uGetInterruptStatus(CONTROLLER_T *CtlP, unsigned int port_number);
//void uEnChannelInterrupt(CONTROLLER_T *CtlP, unsigned int port_number);
//void uDisChannelInterrupt(CONTROLLER_T *CtlP, unsigned int port_number);
void uEnChannelInterrupt(CHANNEL_T *ChP);//BKA 5-30-06
void uDisChannelInterrupt(CHANNEL_T *ChP);//BKA 5-30-06
int uRcvByteParityError(unsigned short bytestatus);
int uRcvByteRcvOverrun(unsigned short bytestatus);
int uRcvByteFramingError(unsigned short bytestatus);
int uRcvByteBreakDetected(unsigned short bytestatus);
int uRcvByteAddressByte(unsigned short bytestatus);
int uRcvByteTimeoutDetected(unsigned short bytestatus);
int uModemReset(CONTROLLER_T *CtlP, unsigned short port_number);
int uSpeakerReset(CONTROLLER_T *CtlP, unsigned short port_number);
void uEnXany(CHANNEL_T *ChP);
void uDisXany(CHANNEL_T *ChP);
void uSetXon(CHANNEL_T *ChP);
void uSetXoff(CHANNEL_T *ChP);
void uEnOneStopBit(CHANNEL_T *ChP);
void uDisOneStopBit(CHANNEL_T *ChP);
void uLoadUcode(CHANNEL_T *ChP);

#endif //  _UNITY_H
 
